@@ -17,11 +17,15 @@ use JSON;
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::PSGI::Constants;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.3';
 
 extends 'Lemonldap::NG::Common::Conf::AccessLib',
   'Lemonldap::NG::Handler::PSGI::Router';
 
+has csp => ( is => 'rw' );
+has brw => ( is => 'rw', default => 0 );
+has dif => ( is => 'rw', default => 0 );
+
 ## @method boolean init($args)
 # Launch initialization method
 #
@@ -50,7 +54,7 @@ sub init {
         return 0;
     }
 
-    $self->{enabledModules} ||= "conf, sessions, notifications";
+    $self->{enabledModules} ||= "conf, sessions, notifications, 2ndFA";
     my @links;
     my @enabledModules =
       map { push @links, $_; "Lemonldap::NG::Manager::" . ucfirst($_) }
@@ -58,6 +62,10 @@ sub init {
     extends 'Lemonldap::NG::Handler::PSGI::Router', @enabledModules;
     my @working;
     my $conf = $self->confAcc->getConf;
+    unless ($conf) {
+        require Lemonldap::NG::Manager::Conf::Zero;
+        $conf = Lemonldap::NG::Manager::Conf::Zero::zeroConf();
+    }
     for ( my $i = 0 ; $i < @enabledModules ; $i++ ) {
         my $mod = $enabledModules[$i];
         no strict 'refs';
@@ -75,10 +83,25 @@ sub init {
     $self->addRoute( links     => 'links',  ['GET'] );
     $self->addRoute( 'psgi.js' => 'sendJs', ['GET'] );
 
+    my $portal = $conf->{portal};
+    $portal =~ s#https?://([^/]*).*#$1#;
+    $self->csp(
+        "default-src 'self' $portal;frame-ancestors 'none';form-action 'self';"
+    );
+    $self->brw( $self->{viewerAllowBrowser}
+          || $conf->{viewerAllowBrowser}
+          || 0 );
+    $self->dif( $self->{viewerAllowDiff} || $conf->{viewerAllowDiff} || 0 );
     $self->defaultRoute( $working[0]->defaultRoute );
 
-    my $linksIcons =
-      { 'conf' => 'cog', 'sessions' => 'duplicate', 'notifications' => 'bell' };
+# Find out more glyphicones at https://www.w3schools.com/icons/bootstrap_icons_glyphicons.asp
+    my $linksIcons = {
+        'conf'          => 'cog',
+        'sessions'      => 'duplicate',
+        'notifications' => 'bell',
+        '2ndFA'         => 'wrench',
+        'viewer'        => 'eye-open',
+    };
 
     $self->links( [] );
     for ( my $i = 0 ; $i < @links ; $i++ ) {
@@ -92,7 +115,13 @@ sub init {
     }
 
     $self->menuLinks( [] );
-    if ( my $portal = Lemonldap::NG::Handler::PSGI::Main->tsv->{portal}->() ) {
+    if (
+        my $portal =
+        $conf->{cfgNum}
+        ? Lemonldap::NG::Handler::PSGI::Main->tsv->{portal}->()
+        : $conf->{portal}
+      )
+    {
         push @{ $self->menuLinks },
           {
             target => $portal,
@@ -109,13 +138,16 @@ sub init {
 }
 
 sub tplParams {
-    return ( VERSION => $VERSION, );
+    my ($self) = @_;
+    return ( VERSION => $VERSION, ALLOWBROWSER => $self->brw );
 }
 
 sub javascript {
     my ($self) = @_;
     return
-      'var formPrefix=staticPrefix+"forms/";var confPrefix=scriptname+"confs/";'
+'var formPrefix=staticPrefix+"forms/";var confPrefix=scriptname+"confs/";var viewPrefix=scriptname+"view/";'
+      . 'var allowDiff='
+      . $self->dif . ';'
       . ( $self->links ? 'var links=' . to_json( $self->links ) . ';' : '' )
       . (
         $self->menuLinks
@@ -124,6 +156,17 @@ sub javascript {
       );
 }
 
+sub sendHtml {
+    my ( $self, $req, $template, %args ) = @_;
+    my $res = $self->SUPER::sendHtml( $req, $template, %args );
+    push @{ $res->[1] },
+      'Content-Security-Policy' => $self->csp,
+      'X-Content-Type-Options'  => 'nosniff',
+      'X-Frame-Options'         => 'DENY',
+      'X-XSS-Protection'        => '1; mode=block';
+    return $res;
+}
+
 1;
 __END__
 
@@ -152,14 +195,14 @@ system.
 
 The Perl part of Lemonldap::NG::Manager is the REST server. Web interface is
 written in Javascript, using AngularJS framework and can be found in `site`
-directory. The REST API is described in REST-API.md file given in source tree.
+directory. The REST API is described in REST-API.md file provided in source tree.
 
-Lemonldap::NG Manager uses L<Plack> to be compatible with CGI, FastCGI,... It
-inherits of L<Lemonldap::NG::Handler::PSGI::Router>
+Lemonldap::NG Manager uses L<Plack> to be CGI, FastCGI and so on compatible.
+It inherits of L<Lemonldap::NG::Handler::PSGI::Router>
 
 =head1 ORGANIZATION
 
-Lemonldap::NG Manager contains 5 parts:
+Lemonldap::NG Manager contains 6 parts:
 
 =over
 
@@ -169,26 +212,28 @@ Lemonldap::NG Manager contains 5 parts:
 
 =item Notification explorer
 
+=item Second Factors manager
+
 =item Configuration builder (see L<Lemonldap::NG::Manager::Build>
 
-=item Command line (see L<Lemonldap::NG::Manager::Cli>
+=item Command line interface (see L<Lemonldap::NG::Manager::Cli>
 
 =back
 
-=head2 Generation of static files
+=head2 Static files generation
 
-The `scripts/jsongenerator.pl` file uses Lemonldap::NG::Manager::Build::Attributes,
+`scripts/jsongenerator.pl` file uses Lemonldap::NG::Manager::Build::Attributes,
 Lemonldap::NG::Manager::Build::Tree and Lemonldap::NG::Manager::Build::CTrees to generate
 
 =over
 
 =item `site/htdocs/static/struct.json`:
 
-the main file that contains the tree view;
+main file containing the tree view;
 
 =item `site/htdocs/static/js/conftree.js`:
 
-generates sub tree for virtualhosts and SAML and OpenID-Connect partners;
+generates Virtualhosts, SAML and OpenID-Connect partners sub-trees;
 
 =item `Lemonldap::NG::Common::Conf::ReConstants`:
 
@@ -218,8 +263,8 @@ you can also fix them in $opts hash ref passed as argument to run() or new()).
   ;                Lemonldap::NG::Handler::PSGI::Router doc.
   protection     = manager
   
-  ;enabledModules: Modules to display. Default to `conf, sessions, notifications`
-  enabledModules = conf, sessions, notifications
+  ;enabledModules: Modules to display. Default to `conf, sessions, notifications, 2ndFA`
+  enabledModules = conf, sessions, notifications, 2ndFA
   
   ;logLevel:       choose one of error, warn, notice, info, debug
   ;                See Lemonldap::NG::Common::PSGI doc for more
@@ -232,7 +277,7 @@ you can also fix them in $opts hash ref passed as argument to run() or new()).
   ;languages:      Available interface languages
   languages      = en, fr
   
-  ;templateDir:    the path to the directory containing HTML templates
+  ;templateDir:    path to the directory containing HTML templates
   ;                See Lemonldap::NG::Common::PSGI doc for more
   templateDir    = /usr/share/lemonldap-ng/manager/
 
@@ -251,7 +296,7 @@ L<http://lemonldap-ng.org/>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 Note that if you want to post a ticket for a conf upload problem, please
 see L<Lemonldap::NG::Manager::Conf::Parser> before.
