@@ -14,7 +14,7 @@
 
 package Lemonldap::NG::Manager::Build::CTrees;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.3';
 
 sub cTrees {
     return {
@@ -36,21 +36,7 @@ sub cTrees {
         samlIDPMetaDataNode => [
             'samlIDPMetaDataXML',
             'samlIDPMetaDataExportedAttributes',
-            {
-                title => 'samlIDPMetaDataOptions',
-                help  => 'authsaml.html#options',
-                form  => 'simpleInputContainer',
-                nodes => [
-                    'samlIDPMetaDataOptionsResolutionRule',
-                    'samlIDPMetaDataOptionsNameIDFormat',
-                    'samlIDPMetaDataOptionsForceAuthn',
-                    'samlIDPMetaDataOptionsIsPassive',
-                    'samlIDPMetaDataOptionsAllowProxiedAuthn',
-                    'samlIDPMetaDataOptionsAllowLoginFromIDP',
-                    'samlIDPMetaDataOptionsRequestedAuthnContext',
-                    'samlIDPMetaDataOptionsRelayStateURL',
-                ],
-            },
+
             {
                 title => "samlIDPMetaDataOptionsSession",
                 form  => 'simpleInputContainer',
@@ -87,6 +73,30 @@ sub cTrees {
                     "samlIDPMetaDataOptionsCheckTime",
                     "samlIDPMetaDataOptionsCheckAudience"
                 ]
+            },
+            {
+                title => 'samlIDPMetaDataOptions',
+                help  => 'authsaml.html#options',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'samlIDPMetaDataOptionsResolutionRule',
+                    'samlIDPMetaDataOptionsNameIDFormat',
+                    'samlIDPMetaDataOptionsForceAuthn',
+                    'samlIDPMetaDataOptionsIsPassive',
+                    'samlIDPMetaDataOptionsAllowProxiedAuthn',
+                    'samlIDPMetaDataOptionsAllowLoginFromIDP',
+                    'samlIDPMetaDataOptionsRequestedAuthnContext',
+                    'samlIDPMetaDataOptionsRelayStateURL',
+                ],
+            },
+            {
+                title => "samlIDPMetaDataOptionsDisplay",
+                form  => 'simpleInputContainer',
+                nodes => [
+                    "samlIDPMetaDataOptionsDisplayName",
+                    "samlIDPMetaDataOptionsIcon",
+                    "samlIDPMetaDataOptionsSortNumber"
+                ]
             }
         ],
         samlSPMetaDataNode => [
@@ -95,8 +105,7 @@ sub cTrees {
             {
                 title => "samlSPMetaDataOptions",
                 help  => 'idpsaml.html#options',
-                nodes => [
-                    {
+                nodes => [ {
                         title => "samlSPMetaDataOptionsAuthnResponse",
                         form  => 'simpleInputContainer',
                         nodes => [
@@ -136,8 +145,7 @@ sub cTrees {
             'oidcOPMetaDataExportedVars',
             {
                 title => 'oidcOPMetaDataOptions',
-                nodes => [
-                    {
+                nodes => [ {
                         title => 'oidcOPMetaDataOptionsConfiguration',
                         form  => 'simpleInputContainer',
                         nodes => [
@@ -164,23 +172,24 @@ sub cTrees {
                             'oidcOPMetaDataOptionsUseNonce'
                         ]
                     },
-                    {
-                        title => 'oidcOPMetaDataOptionsDisplayParams',
-                        form  => 'simpleInputContainer',
-                        nodes => [
-                            'oidcOPMetaDataOptionsDisplayName',
-                            'oidcOPMetaDataOptionsIcon'
-                        ]
-                    },
+                ]
+            },
+            {
+                title => 'oidcOPMetaDataOptionsDisplayParams',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'oidcOPMetaDataOptionsDisplayName',
+                    'oidcOPMetaDataOptionsIcon',
+                    'oidcOPMetaDataOptionsSortNumber'
                 ]
             },
         ],
         oidcRPMetaDataNode => [
             'oidcRPMetaDataExportedVars',
+            'oidcRPMetaDataOptionsExtraClaims',
             {
                 title => 'oidcRPMetaDataOptions',
-                nodes => [
-                    {
+                nodes => [ {
                         title => 'oidcRPMetaDataOptionsAuthentication',
                         form  => 'simpleInputContainer',
                         nodes => [
@@ -188,14 +197,6 @@ sub cTrees {
                             'oidcRPMetaDataOptionsClientSecret'
                         ]
                     },
-                    {
-                        title => 'oidcRPMetaDataOptionsDisplay',
-                        form  => 'simpleInputContainer',
-                        nodes => [
-                            'oidcRPMetaDataOptionsDisplayName',
-                            'oidcRPMetaDataOptionsIcon'
-                        ],
-                    },
                     'oidcRPMetaDataOptionsUserIDAttr',
                     'oidcRPMetaDataOptionsIDTokenSignAlg',
                     'oidcRPMetaDataOptionsIDTokenExpiration',
@@ -215,9 +216,18 @@ sub cTrees {
                     'oidcRPMetaDataOptionsRule',
                 ]
             },
-            'oidcRPMetaDataOptionsExtraClaims',
+            {
+                title => 'oidcRPMetaDataOptionsDisplay',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'oidcRPMetaDataOptionsDisplayName',
+                    'oidcRPMetaDataOptionsIcon'
+                ],
+            },
         ],
         casSrvMetaDataNode => [
+            'casSrvMetaDataExportedVars',
+            'casSrvMetaDataOptionsProxiedServices',
             {
                 title => 'casSrvMetaDataOptions',
                 form  => 'simpleInputContainer',
@@ -225,15 +235,19 @@ sub cTrees {
                     'casSrvMetaDataOptionsUrl',
                     'casSrvMetaDataOptionsRenew',
                     'casSrvMetaDataOptionsGateway',
-                    'casSrvMetaDataOptionsDisplayName',
-                    'casSrvMetaDataOptionsIcon',
                 ]
             },
-            'casSrvMetaDataExportedVars',
-            'casSrvMetaDataOptionsProxiedServices',
-        ],
-        casAppMetaDataNode => [
             {
+                title => 'casSrvMetaDataOptionsDisplay',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'casSrvMetaDataOptionsDisplayName',
+                    'casSrvMetaDataOptionsIcon',
+                    'casSrvMetaDataOptionsSortNumber',
+                ]
+            },
+        ],
+        casAppMetaDataNode => [ {
                 title => 'casAppMetaDataOptions',
                 form  => 'simpleInputContainer',
                 nodes => [
