@@ -8,6 +8,138 @@ function templates(tpl,key) {
     };
   };
   switch(tpl){
+  case 'casAppMetaDataNode':
+    return [
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsService",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsService",
+            "title" : "casAppMetaDataOptionsService"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsRule",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsRule",
+            "title" : "casAppMetaDataOptionsRule"
+         }
+      ],
+      "id" : "casAppMetaDataOptions",
+      "title" : "casAppMetaDataOptions",
+      "type" : "simpleInputContainer"
+   },
+   {
+      "cnodes" : tpl+"s/"+key+"/"+"casAppMetaDataExportedVars",
+      "default" : [
+         {
+            "data" : "cn",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataExportedVars/cn",
+            "title" : "cn",
+            "type" : "keyText"
+         },
+         {
+            "data" : "mail",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataExportedVars/mail",
+            "title" : "mail",
+            "type" : "keyText"
+         },
+         {
+            "data" : "uid",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataExportedVars/uid",
+            "title" : "uid",
+            "type" : "keyText"
+         }
+      ],
+      "id" : tpl+"s/"+key+"/"+"casAppMetaDataExportedVars",
+      "title" : "casAppMetaDataExportedVars",
+      "type" : "keyTextContainer"
+   }
+]
+;
+  case 'casSrvMetaDataNode':
+    return [
+   {
+      "cnodes" : tpl+"s/"+key+"/"+"casSrvMetaDataExportedVars",
+      "default" : [
+         {
+            "data" : "cn",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataExportedVars/cn",
+            "title" : "cn",
+            "type" : "keyText"
+         },
+         {
+            "data" : "mail",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataExportedVars/mail",
+            "title" : "mail",
+            "type" : "keyText"
+         },
+         {
+            "data" : "uid",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataExportedVars/uid",
+            "title" : "uid",
+            "type" : "keyText"
+         }
+      ],
+      "id" : tpl+"s/"+key+"/"+"casSrvMetaDataExportedVars",
+      "title" : "casSrvMetaDataExportedVars",
+      "type" : "keyTextContainer"
+   },
+   {
+      "cnodes" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsProxiedServices",
+      "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsProxiedServices",
+      "title" : "casSrvMetaDataOptionsProxiedServices",
+      "type" : "keyTextContainer"
+   },
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsUrl",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsUrl",
+            "title" : "casSrvMetaDataOptionsUrl"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsRenew",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsRenew",
+            "title" : "casSrvMetaDataOptionsRenew",
+            "type" : "bool"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsGateway",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsGateway",
+            "title" : "casSrvMetaDataOptionsGateway",
+            "type" : "bool"
+         }
+      ],
+      "id" : "casSrvMetaDataOptions",
+      "title" : "casSrvMetaDataOptions",
+      "type" : "simpleInputContainer"
+   },
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsDisplayName",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsDisplayName",
+            "title" : "casSrvMetaDataOptionsDisplayName"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsIcon",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsIcon",
+            "title" : "casSrvMetaDataOptionsIcon"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSortNumber",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSortNumber",
+            "title" : "casSrvMetaDataOptionsSortNumber",
+            "type" : "int"
+         }
+      ],
+      "id" : "casSrvMetaDataOptionsDisplay",
+      "title" : "casSrvMetaDataOptionsDisplay",
+      "type" : "simpleInputContainer"
+   }
+]
+;
   case 'oidcOPMetaDataNode':
     return [
    {
@@ -194,27 +326,33 @@ function templates(tpl,key) {
             "id" : "oidcOPMetaDataOptionsProtocol",
             "title" : "oidcOPMetaDataOptionsProtocol",
             "type" : "simpleInputContainer"
-         },
-         {
-            "_nodes" : [
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsDisplayName",
-                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsDisplayName",
-                  "title" : "oidcOPMetaDataOptionsDisplayName"
-               },
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsIcon",
-                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsIcon",
-                  "title" : "oidcOPMetaDataOptionsIcon"
-               }
-            ],
-            "id" : "oidcOPMetaDataOptionsDisplayParams",
-            "title" : "oidcOPMetaDataOptionsDisplayParams",
-            "type" : "simpleInputContainer"
          }
       ],
       "id" : "oidcOPMetaDataOptions",
       "title" : "oidcOPMetaDataOptions"
+   },
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsDisplayName",
+            "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsDisplayName",
+            "title" : "oidcOPMetaDataOptionsDisplayName"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsIcon",
+            "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsIcon",
+            "title" : "oidcOPMetaDataOptionsIcon"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsSortNumber",
+            "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsSortNumber",
+            "title" : "oidcOPMetaDataOptionsSortNumber",
+            "type" : "int"
+         }
+      ],
+      "id" : "oidcOPMetaDataOptionsDisplayParams",
+      "title" : "oidcOPMetaDataOptionsDisplayParams",
+      "type" : "simpleInputContainer"
    }
 ]
 ;
@@ -246,6 +384,13 @@ function templates(tpl,key) {
       "title" : "oidcRPMetaDataExportedVars",
       "type" : "keyTextContainer"
    },
+   {
+      "cnodes" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
+      "default" : [],
+      "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
+      "title" : "oidcRPMetaDataOptionsExtraClaims",
+      "type" : "keyTextContainer"
+   },
    {
       "_nodes" : [
          {
@@ -266,23 +411,6 @@ function templates(tpl,key) {
             "title" : "oidcRPMetaDataOptionsAuthentication",
             "type" : "simpleInputContainer"
          },
-         {
-            "_nodes" : [
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsDisplayName",
-                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsDisplayName",
-                  "title" : "oidcRPMetaDataOptionsDisplayName"
-               },
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIcon",
-                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIcon",
-                  "title" : "oidcRPMetaDataOptionsIcon"
-               }
-            ],
-            "id" : "oidcRPMetaDataOptionsDisplay",
-            "title" : "oidcRPMetaDataOptionsDisplay",
-            "type" : "simpleInputContainer"
-         },
          {
             "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserIDAttr",
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserIDAttr",
@@ -354,6 +482,11 @@ function templates(tpl,key) {
          },
          {
             "_nodes" : [
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsPostLogoutRedirectUris",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsPostLogoutRedirectUris",
+                  "title" : "oidcRPMetaDataOptionsPostLogoutRedirectUris"
+               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutUrl",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutUrl",
@@ -377,6 +510,7 @@ function templates(tpl,key) {
                   "type" : "select"
                },
                {
+                  "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutSessionRequired",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutSessionRequired",
                   "title" : "oidcRPMetaDataOptionsLogoutSessionRequired",
@@ -386,17 +520,32 @@ function templates(tpl,key) {
             "id" : "logout",
             "title" : "logout",
             "type" : "simpleInputContainer"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
+            "title" : "oidcRPMetaDataOptionsRule"
          }
       ],
       "id" : "oidcRPMetaDataOptions",
       "title" : "oidcRPMetaDataOptions"
    },
    {
-      "cnodes" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
-      "default" : [],
-      "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
-      "title" : "oidcRPMetaDataOptionsExtraClaims",
-      "type" : "keyTextContainer"
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsDisplayName",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsDisplayName",
+            "title" : "oidcRPMetaDataOptionsDisplayName"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIcon",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIcon",
+            "title" : "oidcRPMetaDataOptionsIcon"
+         }
+      ],
+      "id" : "oidcRPMetaDataOptionsDisplay",
+      "title" : "oidcRPMetaDataOptionsDisplay",
+      "type" : "simpleInputContainer"
    }
 ]
 ;
@@ -416,134 +565,6 @@ function templates(tpl,key) {
       "title" : "samlIDPMetaDataExportedAttributes",
       "type" : "samlAttributeContainer"
    },
-   {
-      "_nodes" : [
-         {
-            "default" : "",
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
-            "title" : "samlIDPMetaDataOptionsResolutionRule",
-            "type" : "longtext"
-         },
-         {
-            "default" : "",
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsNameIDFormat",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsNameIDFormat",
-            "select" : [
-               {
-                  "k" : "",
-                  "v" : ""
-               },
-               {
-                  "k" : "unspecified",
-                  "v" : "Unspecified"
-               },
-               {
-                  "k" : "email",
-                  "v" : "Email"
-               },
-               {
-                  "k" : "x509",
-                  "v" : "X509 certificate"
-               },
-               {
-                  "k" : "windows",
-                  "v" : "Windows"
-               },
-               {
-                  "k" : "kerberos",
-                  "v" : "Kerberos"
-               },
-               {
-                  "k" : "entity",
-                  "v" : "Entity"
-               },
-               {
-                  "k" : "persistent",
-                  "v" : "Persistent"
-               },
-               {
-                  "k" : "transient",
-                  "v" : "Transient"
-               },
-               {
-                  "k" : "encrypted",
-                  "v" : "Encrypted"
-               }
-            ],
-            "title" : "samlIDPMetaDataOptionsNameIDFormat",
-            "type" : "select"
-         },
-         {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsForceAuthn",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsForceAuthn",
-            "title" : "samlIDPMetaDataOptionsForceAuthn",
-            "type" : "bool"
-         },
-         {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIsPassive",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIsPassive",
-            "title" : "samlIDPMetaDataOptionsIsPassive",
-            "type" : "bool"
-         },
-         {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowProxiedAuthn",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowProxiedAuthn",
-            "title" : "samlIDPMetaDataOptionsAllowProxiedAuthn",
-            "type" : "bool"
-         },
-         {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowLoginFromIDP",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowLoginFromIDP",
-            "title" : "samlIDPMetaDataOptionsAllowLoginFromIDP",
-            "type" : "bool"
-         },
-         {
-            "default" : "",
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRequestedAuthnContext",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRequestedAuthnContext",
-            "select" : [
-               {
-                  "k" : "",
-                  "v" : ""
-               },
-               {
-                  "k" : "kerberos",
-                  "v" : "Kerberos"
-               },
-               {
-                  "k" : "password-protected-transport",
-                  "v" : "Password protected transport"
-               },
-               {
-                  "k" : "password",
-                  "v" : "Password"
-               },
-               {
-                  "k" : "tls-client",
-                  "v" : "TLS client certificate"
-               }
-            ],
-            "title" : "samlIDPMetaDataOptionsRequestedAuthnContext",
-            "type" : "select"
-         },
-         {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
-            "title" : "samlIDPMetaDataOptionsRelayStateURL",
-            "type" : "bool"
-         }
-      ],
-      "help" : "authsaml.html#options",
-      "id" : "samlIDPMetaDataOptions",
-      "title" : "samlIDPMetaDataOptions",
-      "type" : "simpleInputContainer"
-   },
    {
       "_nodes" : [
          {
@@ -566,6 +587,11 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsStoreSAMLToken",
             "title" : "samlIDPMetaDataOptionsStoreSAMLToken",
             "type" : "bool"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsUserAttribute",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsUserAttribute",
+            "title" : "samlIDPMetaDataOptionsUserAttribute"
          }
       ],
       "id" : "samlIDPMetaDataOptionsSession",
@@ -705,6 +731,157 @@ function templates(tpl,key) {
       "id" : "samlIDPMetaDataOptionsSecurity",
       "title" : "samlIDPMetaDataOptionsSecurity",
       "type" : "simpleInputContainer"
+   },
+   {
+      "_nodes" : [
+         {
+            "default" : "",
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
+            "title" : "samlIDPMetaDataOptionsResolutionRule",
+            "type" : "longtext"
+         },
+         {
+            "default" : "",
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsNameIDFormat",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsNameIDFormat",
+            "select" : [
+               {
+                  "k" : "",
+                  "v" : ""
+               },
+               {
+                  "k" : "unspecified",
+                  "v" : "Unspecified"
+               },
+               {
+                  "k" : "email",
+                  "v" : "Email"
+               },
+               {
+                  "k" : "x509",
+                  "v" : "X509 certificate"
+               },
+               {
+                  "k" : "windows",
+                  "v" : "Windows"
+               },
+               {
+                  "k" : "kerberos",
+                  "v" : "Kerberos"
+               },
+               {
+                  "k" : "entity",
+                  "v" : "Entity"
+               },
+               {
+                  "k" : "persistent",
+                  "v" : "Persistent"
+               },
+               {
+                  "k" : "transient",
+                  "v" : "Transient"
+               },
+               {
+                  "k" : "encrypted",
+                  "v" : "Encrypted"
+               }
+            ],
+            "title" : "samlIDPMetaDataOptionsNameIDFormat",
+            "type" : "select"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsForceAuthn",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsForceAuthn",
+            "title" : "samlIDPMetaDataOptionsForceAuthn",
+            "type" : "bool"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIsPassive",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIsPassive",
+            "title" : "samlIDPMetaDataOptionsIsPassive",
+            "type" : "bool"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowProxiedAuthn",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowProxiedAuthn",
+            "title" : "samlIDPMetaDataOptionsAllowProxiedAuthn",
+            "type" : "bool"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowLoginFromIDP",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsAllowLoginFromIDP",
+            "title" : "samlIDPMetaDataOptionsAllowLoginFromIDP",
+            "type" : "bool"
+         },
+         {
+            "default" : "",
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRequestedAuthnContext",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRequestedAuthnContext",
+            "select" : [
+               {
+                  "k" : "",
+                  "v" : ""
+               },
+               {
+                  "k" : "kerberos",
+                  "v" : "Kerberos"
+               },
+               {
+                  "k" : "password-protected-transport",
+                  "v" : "Password protected transport"
+               },
+               {
+                  "k" : "password",
+                  "v" : "Password"
+               },
+               {
+                  "k" : "tls-client",
+                  "v" : "TLS client certificate"
+               }
+            ],
+            "title" : "samlIDPMetaDataOptionsRequestedAuthnContext",
+            "type" : "select"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
+            "title" : "samlIDPMetaDataOptionsRelayStateURL",
+            "type" : "bool"
+         }
+      ],
+      "help" : "authsaml.html#options",
+      "id" : "samlIDPMetaDataOptions",
+      "title" : "samlIDPMetaDataOptions",
+      "type" : "simpleInputContainer"
+   },
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsDisplayName",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsDisplayName",
+            "title" : "samlIDPMetaDataOptionsDisplayName"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIcon",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsIcon",
+            "title" : "samlIDPMetaDataOptionsIcon"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsSortNumber",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsSortNumber",
+            "title" : "samlIDPMetaDataOptionsSortNumber",
+            "type" : "int"
+         }
+      ],
+      "id" : "samlIDPMetaDataOptionsDisplay",
+      "title" : "samlIDPMetaDataOptionsDisplay",
+      "type" : "simpleInputContainer"
    }
 ]
 ;
@@ -879,6 +1056,11 @@ function templates(tpl,key) {
                   "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsEnableIDPInitiatedURL",
                   "title" : "samlSPMetaDataOptionsEnableIDPInitiatedURL",
                   "type" : "bool"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsRule",
+                  "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsRule",
+                  "title" : "samlSPMetaDataOptionsRule"
                }
             ],
             "id" : "samlSPMetaDataOptionsSecurity",
@@ -981,6 +1163,10 @@ function templates(tpl,key) {
                   "k" : "DevOps",
                   "v" : "DevOps"
                },
+               {
+                  "k" : "DevOpsST",
+                  "v" : "DevOpsST"
+               },
                {
                   "k" : "ServiceToken",
                   "v" : "ServiceToken"
@@ -988,11 +1174,18 @@ function templates(tpl,key) {
             ],
             "title" : "vhostType",
             "type" : "select"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"vhostAuthnLevel",
+            "id" : tpl+"s/"+key+"/"+"vhostAuthnLevel",
+            "title" : "vhostAuthnLevel",
+            "type" : "int"
          }
       ],
       "help" : "configvhost.html#options",
       "id" : "vhostOptions",
-      "title" : "vhostOptions"
+      "title" : "vhostOptions",
+      "type" : "simpleInputContainer"
    }
 ]
 ;
